% *******************************************************************************************************
% Position Aware RFID Systems: The PARIS Simulation Framework
% ***********************************************************
% workaround for bug in Matlab surface plots (rendering)
%    When viewing a surface with linear axes from above (i.e., view([0,90])), intersections with a flat
%    minimum (e.g. a saturated minimum) are visible as white lines (unwanted transparency at intersection 
%    of polygons).
%    Possible reference: http://www.opengl.org/resources/faq/technical/polygonoffset.htm
%
%
%
% ***** Copyright / License / Authors *****
% Copyright 2007, 2008, 2009, 2010 Daniel Arnitz
%   Signal Processing and Speech Communication Laboratory, Graz University of Technology, Austria
%   NXP Semiconductors Austria GmbH Styria, Gratkorn, Austria
%
% This file is part of the PARIS Simulation Framework.
%
% The PARIS Simulation Framework is free software: you can redistribute it and/or modify it under the
% terms of the GNU General Public License as published by the Free Software Foundation, either
% version 3 of the License, or (at your option) any later version.
%
% The PARIS Simulation Framework is distributed in the hope that it will be useful, but WITHOUT ANY
% WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
% See the GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License along with the PARIS Simulation 
% Framework. If not, see <http://www.gnu.org/licenses/>.
%
%
% ***** Behavior *****
% surface_fixlines(x, y, z)
%    Insert a plane below min(min(Z)) spanning the entire range of X and Y.
%
%
% ***** Interface definition *****
% function surface_fixlines(x, y, z)
%    x   vector/matrix containing x axis data
%    y   vector/matrix containing y axis data
%    z   matrix spanning the surface z(x,y)
%
%
% ***** Changelog *****
% REVISION   DATE         USER        DESCRIPTION (! bugfixes, + addons, - removals, ~ otherwise)
% beta 1.0   2010-03-30   arnitz      ~ initial release
%
%
% ***** Todo *****
%
% *******************************************************************************************************

function surface_fixlines(x, y, z)

surface([min(min(x)), max(max(x))], [min(min(y)), max(max(y))], ones(2,2)*min(min(z))-eps, 'EdgeColor','none');
